package
Version:
v0.5.0
Opens a new window with list of versions in this module.
Published: May 11, 2026
License: MIT
Opens a new window with license information.
Imports: 5
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Register mounts Swagger UI and the OpenAPI spec on the given Kratos HTTP server.
- GET {basePath}/ → Swagger UI page
- GET {basePath}/openapi.yaml → raw OpenAPI spec
type Option func(*config)
Source Files
¶
Click to show internal directories.
Click to hide internal directories.